@@ -39,7 +39,9 @@ def _transform(graph, target, source, excluded_edges=None, ooc_types=ooc_types,
             kwargs['dshape'] = discover(x)
     except NotImplementedError:
         pass
-    pth = path(graph, type(source), target, excluded_edges=excluded_edges)
+    pth = path(graph, type(source), target,
+               excluded_edges=excluded_edges,
+               ooc_types=ooc_types)
     try:
         for (A, B, f) in pth:
             oldx = x
@@ -55,7 +57,7 @@ def _transform(graph, target, source, excluded_edges=None, ooc_types=ooc_types,
         return _transform(graph, target, source, excluded_edges=new_exclusions, **kwargs)
 
 
-def path(graph, source, target, excluded_edges=None, ooc_types=None):
+def path(graph, source, target, excluded_edges=None, ooc_types=ooc_types):
     """ Path of functions between two types """
     if not isinstance(source, type):
         source = type(source)
